@@ -15,8 +15,8 @@
 # along with pytrisk. If not, see <https://www.gnu.org/licenses/>.
 #
 
-def main():
-    print('in main')
+def run():
+    print('launching pytrisk')
 
 if __name__ == '__main__':
-    main()
+    run()
